@@ -1,6 +1,16 @@
+skip_on_cran()
+
+# Suppress messages
+sink(file = file(tempfile(), open = "wt"), type = "message")
+
 #Load reference results
 refRes_file <- '../data/refResults.RData'
 load(refRes_file)
+load(file = '../data/npx_data_format221010.RData')
+npx_Check <- suppressWarnings(npxCheck(npx_data_format221010))
+
+#Load data with hidden/excluded assays (all NPX=NA)
+load(file = '../data/npx_data_format221010.RData')
 
 #Run olink_lmer
 lmer_results_1 <- olink_lmer(df = npx_data1,
@@ -48,6 +58,7 @@ lmer_plot_moreProts <- olink_lmer_plot(df = npx_data1,
 test_that("olink_lmer works", {
   expect_equal(lmer_results_1, ref_results$lmer_results_1, tolerance = 1e-4)
   expect_error(olink_lmer(npx_data1))
+  expect_warning(olink_lmer(npx_data_format221010, variable = 'treatment1', random = 'SubjectDummy')) # data with all NPX=NA for some assays
 })
 
 test_that("olink_lmer_posthoc works", {
@@ -59,10 +70,21 @@ test_that("olink_lmer_posthoc works", {
                                       dplyr::filter(term == 'Treatment:Time') %>%
                                       dplyr::filter(Threshold == 'Significant') %>%
                                       dplyr::pull(OlinkID)})) # no effect specified
+
+  expect_warning(olink_lmer_posthoc(df = npx_data_format221010,
+                                    variable = 'treatment1',
+                                    effect = 'treatment1',
+                                    random = 'SubjectDummy')) # data with all NPX=NA for some assays
 })
 
+lmer_plot_excludedids<- suppressWarnings(olink_lmer_plot(df = npx_data_format221010,
+               variable = c('treatment1'),
+               random = "SubjectDummy",
+               olinkid_list = c(npx_Check$all_nas[1:5],"OID30538"),
+               x_axis_variable = "treatment1", number_of_proteins_per_plot = 5))
+
 test_that("olink_lmer_plot works", {
-  skip_on_ci()
   vdiffr::expect_doppelganger('lmer plot', lmer_plot)
   vdiffr::expect_doppelganger('lmer plot more prots than space', lmer_plot_moreProts[[2]])
+  expect_length(unique(lmer_plot_excludedids[[1]]$data$OlinkID), 1)
 })
